
package com.sabre.eps.schemas;

import java.io.Serializable;
import java.util.Date;

/** 
 *  Schemas for Move of a profie from domain to domain

 * 
 * Schema fragment(s) for this class:
 * <pre>
 * &lt;xs:element xmlns:ns="http://www.sabre.com/eps/schemas" xmlns:xs="http://www.w3.org/2001/XMLSchema" name="Sabre_OTA_ProfileDataMgmtRQ">
 *   &lt;xs:complexType>
 *     &lt;xs:choice>
 *       &lt;xs:element type="ns:MoveToDomainType" name="MoveDomainObject"/>
 *       &lt;xs:element type="ns:MoveDomainType" name="MoveDomain"/>
 *       &lt;xs:element type="ns:CopyToDomainType" name="CopyDomainObject"/>
 *       &lt;xs:element type="ns:StatusOfMoveDomainRQType" name="StatusOfMoveDomain"/>
 *     &lt;/xs:choice>
 *     &lt;xs:attribute type="xs:dateTime" use="optional" name="TimeStamp"/>
 *     &lt;xs:attribute use="optional" default="Production" name="Target">
 *       &lt;xs:simpleType>
 *         &lt;!-- Reference to inner class Target -->
 *       &lt;/xs:simpleType>
 *     &lt;/xs:attribute>
 *     &lt;xs:attribute type="xs:string" use="required" name="Version"/>
 *   &lt;/xs:complexType>
 * &lt;/xs:element>
 * </pre>
 */
public class SabreOTAProfileDataMgmtRQ implements Serializable
{
    private int choiceSelect = -1;
    private static final int MOVE_DOMAIN_OBJECT_CHOICE = 0;
    private static final int MOVE_DOMAIN_CHOICE = 1;
    private static final int COPY_DOMAIN_OBJECT_CHOICE = 2;
    private static final int STATUS_OF_MOVE_DOMAIN_CHOICE = 3;
    private MoveToDomainType moveDomainObject;
    private MoveDomainType moveDomain;
    private CopyToDomainType copyDomainObject;
    private StatusOfMoveDomainRQType statusOfMoveDomain;
    private Date timeStamp;
    private Target target;
    private String version;

    private void setChoiceSelect(int choice) {
        if (choiceSelect == -1) {
            choiceSelect = choice;
        } else if (choiceSelect != choice) {
            throw new IllegalStateException(
                    "Need to call clearChoiceSelect() before changing existing choice");
        }
    }

    /** 
     * Clear the choice selection.
     */
    public void clearChoiceSelect() {
        choiceSelect = -1;
    }

    /** 
     * Check if MoveDomainObject is current selection for choice.
     * 
     * @return <code>true</code> if selection, <code>false</code> if not
     */
    public boolean ifMoveDomainObject() {
        return choiceSelect == MOVE_DOMAIN_OBJECT_CHOICE;
    }

    /** 
     * Get the 'MoveDomainObject' element value. *** SABRE ADDED *** Used to move Profiles/Templates across PCC with branch access
     * 
     * @return value
     */
    public MoveToDomainType getMoveDomainObject() {
        return moveDomainObject;
    }

    /** 
     * Set the 'MoveDomainObject' element value. *** SABRE ADDED *** Used to move Profiles/Templates across PCC with branch access
     * 
     * @param moveDomainObject
     */
    public void setMoveDomainObject(MoveToDomainType moveDomainObject) {
        setChoiceSelect(MOVE_DOMAIN_OBJECT_CHOICE);
        this.moveDomainObject = moveDomainObject;
    }

    /** 
     * Check if MoveDomain is current selection for choice.
     * 
     * @return <code>true</code> if selection, <code>false</code> if not
     */
    public boolean ifMoveDomain() {
        return choiceSelect == MOVE_DOMAIN_CHOICE;
    }

    /** 
     * Get the 'MoveDomain' element value. *** SABRE ADDED *** Used to move all data across PCC with branch access
     * 
     * @return value
     */
    public MoveDomainType getMoveDomain() {
        return moveDomain;
    }

    /** 
     * Set the 'MoveDomain' element value. *** SABRE ADDED *** Used to move all data across PCC with branch access
     * 
     * @param moveDomain
     */
    public void setMoveDomain(MoveDomainType moveDomain) {
        setChoiceSelect(MOVE_DOMAIN_CHOICE);
        this.moveDomain = moveDomain;
    }

    /** 
     * Check if CopyDomainObject is current selection for choice.
     * 
     * @return <code>true</code> if selection, <code>false</code> if not
     */
    public boolean ifCopyDomainObject() {
        return choiceSelect == COPY_DOMAIN_OBJECT_CHOICE;
    }

    /** 
     * Get the 'CopyDomainObject' element value. *** SABRE ADDED *** Used to copy Templates across PCC with branch access
     * 
     * @return value
     */
    public CopyToDomainType getCopyDomainObject() {
        return copyDomainObject;
    }

    /** 
     * Set the 'CopyDomainObject' element value. *** SABRE ADDED *** Used to copy Templates across PCC with branch access
     * 
     * @param copyDomainObject
     */
    public void setCopyDomainObject(CopyToDomainType copyDomainObject) {
        setChoiceSelect(COPY_DOMAIN_OBJECT_CHOICE);
        this.copyDomainObject = copyDomainObject;
    }

    /** 
     * Check if StatusOfMoveDomain is current selection for choice.
     * 
     * @return <code>true</code> if selection, <code>false</code> if not
     */
    public boolean ifStatusOfMoveDomain() {
        return choiceSelect == STATUS_OF_MOVE_DOMAIN_CHOICE;
    }

    /** 
     * Get the 'StatusOfMoveDomain' element value.
     * 
     * @return value
     */
    public StatusOfMoveDomainRQType getStatusOfMoveDomain() {
        return statusOfMoveDomain;
    }

    /** 
     * Set the 'StatusOfMoveDomain' element value.
     * 
     * @param statusOfMoveDomain
     */
    public void setStatusOfMoveDomain(
            StatusOfMoveDomainRQType statusOfMoveDomain) {
        setChoiceSelect(STATUS_OF_MOVE_DOMAIN_CHOICE);
        this.statusOfMoveDomain = statusOfMoveDomain;
    }

    /** 
     * Get the 'TimeStamp' attribute value. Indicates the creation date and time of the message in UTC using the following format specified by ISO 8601; YYYY-MM-DDThh:mm:ssZ with time values using the 24 hour clock (e.g. 20 November 2003, 1:59:38 pm UTC becomes 2003-11-20T13:59:38Z).
     * 
     * @return value
     */
    public Date getTimeStamp() {
        return timeStamp;
    }

    /** 
     * Set the 'TimeStamp' attribute value. Indicates the creation date and time of the message in UTC using the following format specified by ISO 8601; YYYY-MM-DDThh:mm:ssZ with time values using the 24 hour clock (e.g. 20 November 2003, 1:59:38 pm UTC becomes 2003-11-20T13:59:38Z).
     * 
     * @param timeStamp
     */
    public void setTimeStamp(Date timeStamp) {
        this.timeStamp = timeStamp;
    }

    /** 
     * Get the 'Target' attribute value. Used to indicate whether the request is for the Test or Production system.
     * 
     * @return value
     */
    public Target getTarget() {
        return target;
    }

    /** 
     * Set the 'Target' attribute value. Used to indicate whether the request is for the Test or Production system.
     * 
     * @param target
     */
    public void setTarget(Target target) {
        this.target = target;
    }

    /** 
     * Get the 'Version' attribute value. For all OTA versioned messages, the version of the message is indicated by a decimal value.
     * 
     * @return value
     */
    public String getVersion() {
        return version;
    }

    /** 
     * Set the 'Version' attribute value. For all OTA versioned messages, the version of the message is indicated by a decimal value.
     * 
     * @param version
     */
    public void setVersion(String version) {
        this.version = version;
    }
    /** 
     * Schema fragment(s) for this class:
     * <pre>
     * &lt;xs:simpleType xmlns:xs="http://www.w3.org/2001/XMLSchema">
     *   &lt;xs:restriction base="xs:string">
     *     &lt;xs:enumeration value="Test"/>
     *     &lt;xs:enumeration value="Production"/>
     *   &lt;/xs:restriction>
     * &lt;/xs:simpleType>
     * </pre>
     */
    public static enum Target implements Serializable {
        TEST("Test"), PRODUCTION("Production");
        private final String value;

        private Target(String value) {
            this.value = value;
        }

        public String xmlValue() {
            return value;
        }

        public static Target convert(String value) {
            for (Target inst : values()) {
                if (inst.xmlValue().equals(value)) {
                    return inst;
                }
            }
            return null;
        }
    }
}
